# For loop transformation

Based on https://sadh.life/post/cursed-for/ and https://github.com/tusharsadhwani/cursed-for/tree/master/approach/the_truly_cursed_way

Check out run.py to run this example.

```shell
$ python ./run.py
```
